Documentation
¶
Overview ¶
Package tz contains timezone lists.
Index ¶
- Variables
- type Zone
- func (t *Zone) Display() string
- func (t *Zone) Loc() *time.Location
- func (t Zone) MarshalText() ([]byte, error)
- func (t *Zone) Offset() int
- func (t *Zone) OffsetDisplay() string
- func (t *Zone) OffsetDuration() time.Duration
- func (t *Zone) OffsetRFC3339() string
- func (t *Zone) Scan(v any) error
- func (t *Zone) String() string
- func (t *Zone) UnmarshalText(v []byte) error
- func (t Zone) Value() (driver.Value, error)
Constants ¶
This section is empty.
Variables ¶
var UTC = &Zone{CountryCode: "", Zone: "UTC", Abbr: []string{"UTC"}, CountryName: "UTC", Comments: "", Location: time.UTC}
UTC timezone.
var Zones = []*Zone{}/* 423 elements not displayed */
Zones is a list of all timezones by country.
Functions ¶
This section is empty.
Types ¶
type Zone ¶
type Zone struct {
*time.Location
CountryCode string // ID
Zone string // Asia/Makassar
Abbr []string // WITA – the correct abbreviation may change depending on the time of year (i.e. CET and CEST, depending on DST).
CountryName string // Indonesia
Comments string // Borneo (east, south); Sulawesi/Celebes, Bali, Nusa Tengarra; Timor (west)
// contains filtered or unexported fields
}
Zone represents a time zone.
func New ¶
New timezone from country code and zone name. The country code is only informative, and may be blank or wrong, in which case it will load the first zone found.
func (Zone) MarshalText ¶
MarshalText converts the data to a human readable representation.
func (*Zone) OffsetDisplay ¶
OffsetDisplay gets the offset as a human readable string: "UTC +8:00", "UTC -7:30", "UTC".
Note that this displays the offset that is currently valid. For example Europe/Berlin may be +0100 or +0200, depending on whether DST is in effect.
func (*Zone) OffsetDuration ¶
OffsetDuration gets the timezone offset.
func (*Zone) OffsetRFC3339 ¶
OffsetRFC3339 gets the offset as a RFC3339 string: "+08:00", "-07:30", "UTC".
Note that this displays the offset that is currently valid. For example Europe/Berlin may be +0100 or +0200, depending on whether DST is in effect.
func (*Zone) UnmarshalText ¶
UnmarshalText parses text in to the Go data structure.